NMF by alternating non-negative least squares using projected gradients. For a reference to the method, see C.-J. Lin, "Projected Gradient Methods for Non-negative Matrix Factorization", Neural computation 19.10 (2007): 2756-2779.
PGNMF(X, nmfMod, tol = 1e-05, maxIter = 500, timeLimit = 300,
checkDivergence = TRUE)Input data matrix, each column represents one data point and the rows correspond to the different features
Valid NMF model, containing initialized factor matrices (in accordance with the NMF package definition)
Tolerance for a relative stopping condition
Maximum number of iterations
Limit of time duration NMF analysis
Boolean indicating whether divergence checking should be performed Default is TRUE, but it should be set to FALSE when using random initialization
Resulting NMF model (in accordance with the NMF package definition)